window.Gleam.initSearch([{"doc":"cgi","title":"cgi","content":"# cgi\n\nCommon Gateway Interface (CGI) in Gleam.\n\n[![Package Version](https://img.shields.io/hexpm/v/cgi)](https://hex.pm/packages/cgi)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/cgi/)\n\nCGI is not commonly used these days, but there scenarios where it is still a\ngood choice. As CGI programs only run when there is a request to handle they do\nnot use any system resources when there is no traffic. This makes them very\nefficient for low traffic websites.\n\n```sh\ngleam add cgi\n```\n```gleam\nimport cgi\nimport gleam/string\n\npub fn main() {\n  use request &lt;- cgi.handle_request\n  let headers = [#(&quot;content-type&quot;, &quot;text/plain&quot;)]\n  let body = &quot;Hello! You send me this request:\\n\\n&quot; &lt;&gt; string.inspect(request)\n  Response(201, headers, body)\n}\n```\n\nYou may wish to [compile your Gleam program to an escript](https://github.com/lpil/gleescript)\nto be run by your CGI server.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/cgi&gt;.\n\nThank you to Steven vanZyl for [plug_cgi][1], which was used as a\nreference. Why is there so little information on the CGI protcol online\nthese days?\n\n[1]: https://github.com/rushsteve1/plug_cgi\n","url":"index.html"},{"doc":"cgi","title":"handle_request","content":"pub fn handle_request(\n  f: fn(Request(BitArray)) -&gt; Response(String),\n) -&gt; Nil\n Load a GCI HTTP request and dispatch a response.\n\n CGI works over stdin and stdout, so be sure your code does not use them for\n this will likely cause the program to fail.\n\nSynonyms:\ncgi.handle_request\ncgi handle_request","url":"cgi.html#handle_request"},{"doc":"cgi","title":"load_request","content":"pub fn load_request() -&gt; Request(BitArray)\n Load a CGI HTTP request from the environment.\n\n The body of the request is not loaded. Use `read_body` or\n `with_request_body` to load the body into the request.\n\nSynonyms:\ncgi.load_request\ncgi load_request","url":"cgi.html#load_request"},{"doc":"cgi","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\ncgi.main\ncgi main","url":"cgi.html#main"},{"doc":"cgi","title":"read_body","content":"pub fn read_body(request: Request(BitArray)) -&gt; Request(BitArray)\n Load the body of a request from stdin.\n\n Due to how IO works in JavaScript may not always work on JavaScript,\n especially if the body ir larger or on Windows. Consider using the\n `with_request_body` function instead, which works on all platforms.\n\nSynonyms:\ncgi.read_body\ncgi read_body","url":"cgi.html#read_body"},{"doc":"cgi","title":"send_response","content":"pub fn send_response(response: Response(String)) -&gt; Nil\n Send a CGI HTTP response by printing it to stdout.\n\nSynonyms:\ncgi.send_response\ncgi send_response","url":"cgi.html#send_response"},{"doc":"cgi","title":"with_request_body","content":"pub fn with_request_body(\n  request: Request(BitArray),\n  handle: fn(Request(BitArray)) -&gt; a,\n) -&gt; Nil\n Load the body of a request from stdin, running a callback with the\n response with the body.\n\nSynonyms:\ncgi.with_request_body\ncgi with_request_body","url":"cgi.html#with_request_body"},{"doc":"cgi","title":"cgi","content":"","url":"cgi.html"}]);